pub struct InputActionState<'w, A: InputAction> { /* private fields */ }Expand description
Provides read-only access to the current state of an input action.
An action may be in either:
Activestatus: The action is currently active and has an associated value.Idlestatus: The action is not active.
Usage
Use this type in systems that need to read the state of an input action.
Notes
- The state is updated every frame based on the values
poured into the
InputActionDrain. - To check if the action is active without cloning the
value, use
InputActionState::is_active.
Implementations
Sourceimpl<A: InputAction> InputActionState<'_, A>
impl<A: InputAction> InputActionState<'_, A>
Sourcepub fn state(&self) -> Option<A>
pub fn state(&self) -> Option<A>
Returns the current state of the input action.
The input action can be in one of two statuses:
Active: The action is currently active, and this method returnsSome(value).Idle: The action is not active, and this method returnsNone.
Notes
- If the action is
Active, this method clones the associated value. If you only need to check whether the action is active (without cloning the value), useInputActionState::is_active. - Cloning the value may have a performance cost, so avoid calling this method repeatedly if you only need to check the active status.